#!/bin/sh

echo "+++++ Checking current user rights..."

if [ "$(id -u root)" = "$(id -u)" ] ; then
    :
else
    echo "ERROR: The current user id is not root (`id|awk '{print $1}'`)."
    exit 1
fi
echo

if [ "X$ACTIANZEN_ROOT" = "X" ] ; then
    ACTIANZEN_ROOT=/usr/local/actianzen
    export ACTIANZEN_ROOT=$ACTIANZEN_ROOT
fi

PATH=$ACTIANZEN_ROOT/bin:$PATH

if [ $(uname -s) = "Darwin" ]
then
    DYLD_LIBRARY_PATH=$ACTIANZEN_ROOT/bin:$ACTIANZEN_ROOT/lib:$ACTIANZEN_ROOT/lib64:$DYLD_LIBRARY_PATH
    export DYLD_LIBRARY_PATH
    SO_EXTENSION="dylib"
    SU_ARGS="-l"
else
    LD_LIBRARY_PATH=$ACTIANZEN_ROOT/bin:$ACTIANZEN_ROOT/lib:$ACTIANZEN_ROOT/lib64:$LD_LIBRARY_PATH
    export LD_LIBRARY_PATH
    SO_EXTENSION="so"
    SU_ARGS=
fi

export ACTIANZEN_ROOT
USERNAME=zen-svc
GROUPNAME=zen-data

echo "+++++ Setting up symbolic links for libraries..."

# These used to be in the RPM spec file, but we moved them
# here for tarball installs.
rm -f $ACTIANZEN_ROOT/lib/libbtrvif.${SO_EXTENSION}

LDCONFIG=/sbin/ldconfig
if [ ! -x $LDCONFIG ] ; then
    LDCONFIG=/usr/sbin/ldconfig
fi

if [ ! $(uname -s) = "Darwin" ]
then
    # Use ldconfig to create links to major versions
    # selinux: ldconfig runs in its own domain and may not have
    # permissions to write to tty.
    $LDCONFIG -n $ACTIANZEN_ROOT/lib 2>&1 | cat

    MIF_FILE=`ls -1 $ACTIANZEN_ROOT/lib/libpsqlmif.${SO_EXTENSION}.?? 2> /dev/null | tail -1`
    PSQL_VER=`echo $MIF_FILE | sed -e 's/.*[.]\(.*\)/\1/'`
    PS_VER=$PSQL_VER

    dso_symlink () {
        dso=$1
        ver=$2
        if [ -f $ACTIANZEN_ROOT/lib/$dso.$ver ]; then
            (cd $ACTIANZEN_ROOT/lib; ln -sf $dso.$ver $dso )
        fi
    }
else
    MIF_FILE=`ls -1 $ACTIANZEN_ROOT/lib/libpsqlmif.${SO_EXTENSION}.[0-9]* 2> /dev/null | tail -1`
    PSQL_VER=`echo $MIF_FILE | sed -e 's/^.*\.'"${SO_EXTENSION}"'\.\([0-9]*\)\..*$/\1/'`
    PS_VER=$PSQL_VER

    dso_symlink () {
      dso=$1
      ver=$2
      if [ -f $ACTIANZEN_ROOT/lib/$dso.$ver.[0-9]*.* ]; then
          (cd $ACTIANZEN_ROOT/lib; ln -sf $dso.$ver.[0-9]*.* $dso.$ver ; ln -sf $dso.$ver $dso )
      fi
    }

    dso_symlink libclientrb.${SO_EXTENSION} $PSQL_VER
    dso_symlink libcsi100.${SO_EXTENSION} $PSQL_VER
    dso_symlink libdbcsipxy.${SO_EXTENSION} $PSQL_VER
    dso_symlink libdcm100.${SO_EXTENSION} $PSQL_VER
    dso_symlink libenginelm.${SO_EXTENSION} $PSQL_VER
    dso_symlink libexp010.${SO_EXTENSION} $PSQL_VER
    dso_symlink liblegacylm.${SO_EXTENSION} $PSQL_VER
    dso_symlink liblicmgrrb.${SO_EXTENSION} $PSQL_VER
    dso_symlink libmkc3.${SO_EXTENSION} $PSQL_VER
    dso_symlink libmkderb.${SO_EXTENSION} $PSQL_VER
    dso_symlink libodbccr.${SO_EXTENSION} 1
    dso_symlink libpceurop.${SO_EXTENSION} $PS_VER
    dso_symlink libpctlgrb.${SO_EXTENSION} $PSQL_VER
    dso_symlink libpscl.${SO_EXTENSION} $PS_VER
    dso_symlink libpscore.${SO_EXTENSION} $PS_VER
    dso_symlink libpscp932.${SO_EXTENSION} $PS_VER
    dso_symlink libpsdom.${SO_EXTENSION} $PS_VER
    dso_symlink libpseucjp.${SO_EXTENSION} $PS_VER
    dso_symlink libpssax.${SO_EXTENSION} $PS_VER
    dso_symlink libpsutilrb.${SO_EXTENSION} $PS_VER
    dso_symlink libsrderb.${SO_EXTENSION} $PSQL_VER
    dso_symlink libupiapirb.${SO_EXTENSION} $PSQL_VER
    dso_symlink libxlate.${SO_EXTENSION} $PSQL_VER
fi

dso_symlink libodbc.${SO_EXTENSION} 1
dso_symlink libpsqldti.${SO_EXTENSION} $PSQL_VER
dso_symlink libclientlm.${SO_EXTENSION} $PSQL_VER

dso_symlink libels.${SO_EXTENSION} '*.*.*.*'

dso_symlink libbtrieveC.${SO_EXTENSION} $PSQL_VER
dso_symlink libbtrieveCpp.${SO_EXTENSION} $PSQL_VER
dso_symlink libpsqlmif.${SO_EXTENSION} $PSQL_VER
dso_symlink libpsqlnsl.${SO_EXTENSION} $PSQL_VER
dso_symlink libpsqlcsm.${SO_EXTENSION} $PSQL_VER
dso_symlink libpsqlcsp.${SO_EXTENSION} $PSQL_VER
dso_symlink libodbcci.${SO_EXTENSION} $PSQL_VER
dso_symlink libcsi100.${SO_EXTENSION} $PSQL_VER

cd $ACTIANZEN_ROOT/lib 
ln -sf pam_pvsw.${SO_EXTENSION}.1.0 pam_pvsw.${SO_EXTENSION}
ln -sf libpsqlmif.${SO_EXTENSION} libbtrvif.${SO_EXTENSION}
ln -sf libodbcci.${SO_EXTENSION} odbcci.${SO_EXTENSION} 
cd $ACTIANZEN_ROOT 
echo

SELINUX_ENABLED=/usr/sbin/selinuxenabled

if [ -x $SELINUX_ENABLED ] && $SELINUX_ENABLED; then
    /sbin/restorecon -R $ACTIANZEN_ROOT
    if [ -d "$ACTIANZEN_ROOT"/lib ]
    then
    /usr/bin/chcon -t textrel_shlib_t "$ACTIANZEN_ROOT"/lib/*.so "$ACTIANZEN_ROOT"/lib/*.so.*
    fi
fi


echo "+++++ Registering the PCOM libraries..."

# Sym links must already exist
dso_register () {
    dso=$1
    ver=$2
    if [ -f $ACTIANZEN_ROOT/lib/$dso.$ver ]; then
        $ACTIANZEN_ROOT/bin/psregsvr $ACTIANZEN_ROOT/lib/$dso.$ver
        if [ $? -ne 0 ]; then
            echo ERROR: PCOM registration failed for $dso.$ver.
    	    exit 1;
    	fi
    fi
}
dso_register libpctlgrb.${SO_EXTENSION} $PSQL_VER
dso_register libpceurop.${SO_EXTENSION} $PS_VER
dso_register libpssax.${SO_EXTENSION} $PS_VER
dso_register libpsdom.${SO_EXTENSION} $PS_VER
dso_register libpsutilrb.${SO_EXTENSION} $PS_VER
dso_register libclientrb.${SO_EXTENSION} $PSQL_VER
dso_register libupiapirb.${SO_EXTENSION} $PSQL_VER
dso_register libcsi100.${SO_EXTENSION} $PSQL_VER
dso_register libmkc3.${SO_EXTENSION} $PSQL_VER
dso_register libpvmsgrb.${SO_EXTENSION} $PSQL_VER
dso_register libpsqlcsm.${SO_EXTENSION} $PSQL_VER
dso_register libpsqlcsp.${SO_EXTENSION} $PSQL_VER
dso_register libdbcsipxy.${SO_EXTENSION} $PSQL_VER
dso_register libpsqlmpm.${SO_EXTENSION} $PSQL_VER
dso_register libpscp932.${SO_EXTENSION} $PS_VER
dso_register libsrderb.${SO_EXTENSION} $PSQL_VER


echo "+++++ Making user $USERNAME owner of all files in $ACTIANZEN_ROOT/lib and $ACTIANZEN_ROOT/bin..."
chown -f $USERNAME:$GROUPNAME $ACTIANZEN_ROOT
chown -Rf $USERNAME:$GROUPNAME $ACTIANZEN_ROOT/lib
chown -Rf $USERNAME:$GROUPNAME $ACTIANZEN_ROOT/bin
chown -f $USERNAME:$GROUPNAME $ACTIANZEN_ROOT/etc

echo Install has completed.

echo
